==> lms-1.8.0rc5.tar.gz: lms/modules/nodescan.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: nodescan.php,v 1.23.2.1 2005/12/07 08:56:21 alec Exp $
 */

if($_GET['ownerid'] && $LMS->CustomerExists($_GET['ownerid']))
{
	$SMARTY->assign('assignments', $LMS->GetCustomerAssignments($_GET['ownerid']));
	$SMARTY->assign('customergroups', $LMS->CustomergroupGetForCustomer($_GET['ownerid']));
	$SMARTY->assign('othercustomergroups', $LMS->GetGroupNamesWithoutCustomer($_GET['ownerid']));
	$SMARTY->assign('tariffs', $LMS->GetTariffs());
	$SMARTY->assign('customerinfo', $LMS->GetCustomer($_GET['ownerid']));
	$SMARTY->assign('balancelist', $LMS->GetCustomerBalanceList($_GET['ownerid']));
}

$layout['pagetitle'] = trans('Nodes Scanning');

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('nodes',$LMS->ScanNodes());
$SMARTY->display('nodescan.html');

?>

==> lms-1.10.2.tar.gz: lms/modules/nodescan.php <==
<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: nodescan.php,v 1.28.2.1 2007/08/17 13:15:26 alec Exp $
 */

if($_GET['ownerid'] && $LMS->CustomerExists($_GET['ownerid']))
{
	$SMARTY->assign('assignments', $LMS->GetCustomerAssignments($_GET['ownerid']));
	$SMARTY->assign('customergroups', $LMS->CustomergroupGetForCustomer($_GET['ownerid']));
	$SMARTY->assign('othercustomergroups', $LMS->GetGroupNamesWithoutCustomer($_GET['ownerid']));
	$SMARTY->assign('customernodes', $LMS->GetCustomerNodes($_GET['ownerid']));
	$SMARTY->assign('documents', $LMS->GetDocuments($_GET['ownerid'], 10));
	$SMARTY->assign('tariffs', $LMS->GetTariffs());
	$SMARTY->assign('customerinfo', $LMS->GetCustomer($_GET['ownerid']));
	$SMARTY->assign('balancelist', $LMS->GetCustomerBalanceList($_GET['ownerid']));

	if(isset($CONFIG['phpui']['ewx_support']) && chkconfig($CONFIG['phpui']['ewx_support']))
	{
    		$SMARTY->assign('ewx_channelid', $DB->GetOne('SELECT MAX(channelid) FROM ewx_stm_nodes, nodes
	                                        WHERE nodeid = nodes.id AND ownerid = ?', array($_GET['ownerid'])));
	}
}

$layout['pagetitle'] = trans('Nodes Scanning');

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('nodes',$LMS->ScanNodes());
$SMARTY->display('nodescan.html');

?>
